@@ -15,7 +15,9 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-"""Publish a sample encapsulated in Protocol Buffers to Riemann
+"""Publishes samples to Riemann by encapsulating in Protocol Buffers
+   packet(s). All protobufs encapsulation is handled by the bernhard
+   module.
 """
 
 from ceilometer import publisher
@@ -31,7 +33,7 @@ from oslo.config import cfg
 LOG = log.getLogger(__name__)
 
 METER_PUBLISH_OPTS = [
-    cfg.StrOpt('port',
+    cfg.IntOpt('port',
                default=5555,
                help='The default port on which Riemann listens',
                ),
@@ -40,12 +42,20 @@ METER_PUBLISH_OPTS = [
                help='The default transport over which events should be sent '
                     'to a Riemann server (tcp or udp)',
                ),
-    cfg.StrOpt('default_ttl',
+    cfg.IntOpt('default_ttl',
                default=86400,
                help='The default amount of time in seconds that events sent '
                     'to Riemann are retained in its index. Any event that '
                     'passes through Ceilometer with a metadata attribute '
-                    'of "ttl" will override this value.')
+                    'of "ttl" will override this value.'),
+    cfg.StrOpt('default_host',
+               default='openstack',
+               help='The host value used when no other host value is '
+                    'determined, such as from sample resource_metadata.'),
+    cfg.StrOpt('default_state',
+               default='ok',
+               help='The state value used when no other state value is '
+                    'determined, such as from sample resource_metadata.'),
 ]
 
 
@@ -106,6 +116,10 @@ class RiemannPublisher(publisher.PublisherBase):
         # TODO: move attributes construction to helper method
         ignore_metadata_keys = ['host', 'ttl']
 
+        # Use context arg to squash code smell warnings; remove this
+        # if the context is ever needed
+        del context
+
         try:
             if not self.client.connection:
                 self.client.connect()
@@ -119,18 +133,24 @@ class RiemannPublisher(publisher.PublisherBase):
                                                 'host': self.host,
                                                 'port': self.port})
             try:
-                host = 'openstack'
+                host = cfg.CONF.publisher_riemann.default_host
                 ttl = cfg.CONF.publisher_riemann.default_ttl
+                # TODO: any sample data that can be used for state?
+                state = cfg.CONF.publisher_riemann.default_state
                 attributes = {}
-                state = 'ok'  # TODO: sample data that can be used for this?
                 description = ''  # TODO
                 tags = []  # TODO
 
                 if sample.resource_metadata:
                     host = sample.resource_metadata.get('host', host)
                     ttl = sample.resource_metadata.get('ttl', ttl)
+
+                    LOG.trace('Attributes:')
+                    for k, v in sample.resource_metadata.iteritems():
+                        LOG.trace('    %s: %s' % (k, v))
+
                     attributes = {k: v for k, v
-                                  in sample.resource_metadata.iter_items()
+                                  in sample.resource_metadata.iteritems()
                                   if k not in ignore_metadata_keys}
 
                 event = {'time': int(time.time()),
